#ifndef __SPRITE_OBJECTS_H
#define __SPRITE_OBJECTS_H

#include "QwSpriteField.h"
#include "defines.h"

class SunSprite:public QwSprite
{
public:
   SunSprite(QwSpritePixmapSequence *seq);
   virtual int rtti() const {return S_SUN;};
};

class MobileSprite:public QwRealMobileSprite
{
public:
   MobileSprite(QwSpritePixmapSequence *seq,int pn);
   MobileSprite(int pn);

   virtual void forward(double mult,int frame);
   virtual void forward(double mult);

   bool isStopped() {return stopped;}
   void stop(bool s=true) {stopped=s;}
   int getPlayerNumber() {return playerNumber;}
private:
   bool stopped;
   int playerNumber;
};


class ShipSprite:public MobileSprite
{
public:
   ShipSprite(QwSpritePixmapSequence *seq,int pn);
   ShipSprite(int pn);
   virtual int rtti() const {return S_SHIP;};
   int getHitPoints() {return hitpoints;};
   void setHitPoints(int hp) {hitpoints=(hp<0?0:hp);};
   float getEnergy() {return energy;};
   void setEnergy(float e) {energy=(e<0?0:e);};
   void setWins(int w) {wins=w;};
   int getWins() {return wins;};
   void setExplosion(int f) {explosion=f;};
   int getExplosion() {return explosion;};
   void setRotation(float r);
   float getRotation() {return rotation;};
   bool explodes() {return explosion>=0;};
   virtual void forward(double mult);
   virtual void forward(double mult,int fr);
private:
   int hitpoints, wins, explosion;
   float energy,rotation;
};

class BulletSprite:public MobileSprite
{
public:
   BulletSprite(QwSpritePixmapSequence *seq,int pn);
   BulletSprite(int pn);
   virtual int rtti() const {return S_BULLET;};
};

class MineSprite:public MobileSprite
{
public:
   MineSprite(QwSpritePixmapSequence *seq,int pn,float atime,float f);
   MineSprite(int pn,float atime,float f);
   virtual int rtti() const {return S_MINE;};
   bool isActive() {return active;};
   float getFuel() {return fuel;};
   void setFuel(float f) {fuel=(f<0.0?0.0:f);};
   virtual void forward(double mult);
   void explode(QwSpritePixmapSequence* s);
   bool explodes() {return expl;};
   bool over() {return (expl&&(explosiontime>(timeToGo-0.1)));};
private:
   bool expl,active;
   float activateTime,fuel,timeToGo,explosiontime;
};

class ExplosionSprite:public QwRealSprite
{
public:
   ExplosionSprite(QwSpritePixmapSequence *seq,MobileSprite *sp);
   ExplosionSprite(MobileSprite *sp);
   virtual int rtti() const {return S_EXPLOSION;};
   bool isOver() {return over;};
   virtual void forward();
   static void setExplosionSpeed(float sp) {explosionSpeed=sp;};
   void setSequence(QwSpritePixmapSequence *seq);
private:
   static float explosionSpeed;
   float timeToGo,time;
   bool over;
   MobileSprite *obj;
};

#endif
